/**
 * Declares new "kinds" within TypeDoc.
 *
 * A "kind" is a way for TypeDoc to understand how to document something.  Mostly, these have a 1:1 relationship with some sort of TypeScript concept.  This is unsuitable for our purposes, since there's no notion of a "command" or "execute method" in TypeScript.  To that end, we must create new ones.
 *
 * Note that _creating new `ReflectionKind`s is a hack_ and is not supported by TypeDoc. This is the reason you will see `as any` wherever a {@linkcode AppiumPluginReflectionKind} is used.
 *
 * @module
 */
/**
 * Extends the TypeDoc's `ReflectionKind` to add namespaced kinds
 */
export declare enum AppiumPluginReflectionKind {
    Driver,
    Plugin,
    Command,
    ExecuteMethod,
    Extension,
    Any
}
/**
 * The values here are internally computed by TypeDoc, but we need to use them to filter on
 * "groups" for display (since there's no direct relationship from a `ReflectionGroup` back to a `ReflectionKind`).
 */
export declare const AppiumPluginReflectionKindGroupTitles: Set<string>;
//# sourceMappingURL=kind.d.ts.map